Example Scripts for Decoding
----------------------------

This directory contains scripts that use features extracted from neuroimaging data to predict subject-specific observable quantities such as behavioural traits or demographics.

We have examples for:

- Decoding based on static (time-averaged) features: `static`.
- Decoding based on HMM features: `hmm`.
